##  Step 5: Assign Access Control to Existing Fact Sheets
### Assigning Access Control Entities Through Import
It’s best to use the import option to assign the access control entities in bulk for a large number of existing fact sheets. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
  1. Navigate to the Inventory.
  2. Change to the table view.
  3. Select the columns for Read access and Write access.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d7eec7a441014a6148dd7029b81ed_LowRes.png)
  4. Export the Excel file.
  5. In the Excel file, add the access control entities for each fact sheet.
You can add more than one access control entity per fact sheet.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275091f67a4410148be6f0484f01409f_LowRes.png)
  6. Import the updated Excel file.


### Assigning Access Control Entities in the Inventory Table View
The table view of the inventory offers an overview of access permissions. In the table, you have quick access to a dropdown to configure access control entities for each fact sheet and easily navigate between fact sheets.
  1. Navigate to the Inventory.
  2. Change to the table view.
  3. Select the columns for Read access and Write access.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a99c97a44101497c2a07a91f20919_LowRes.png)
  4. Choose Edit.
  5. Choose a field with Read access or Write access and start typing.
The available access control entities are displayed in a dropdown. You can add more than one access control entity for each fact sheet.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b89657a4410149087dca58fc4909a_LowRes.png)
  6. Update all required fact sheets manually.
  7. Choose Save.


### Assigning Access Control Entities for a Single Fact Sheet
You can update the access permissions directly in the fact sheet settings.
  1. Navigate to the fact sheet.
  2. On the Fact Sheet tab, go to the Access Control List (optional) section.
  3. Choose Edit.
  4. Choose a field with Read access or Write access.
The available access control entities are displayed in a dropdown. You can add more than one access control entity for each fact sheet.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275332fa7a441014b3e6a2075dd55695_LowRes.png)
